**
** THE AE MODEL APPLIED TO CONTINUOUS BIRTH WEIGHT DATA
**

version 9.2
set more off

** read data
insheet using mfbraw.txt, clear

** reshape to long
reshape long bwt parity mothage byr male, i(family) j(member)

** transform variables
gen first = parity==0 & parity<.
generate birthyr = byr - 67
generate midage = mothage>=20&mothage<=35 if mothage<.
generate highage = mothage>35 if mothage<.

gen M = member==1
gen F = member==2
gen C = member==3

gen var1 = M+C/2
gen var2 = F+C/2
gen var3 = C/sqrt(2)

** Estimate model as described in Section 7.1

xtmixed bwt male first midage highage birthyr  || family: var1 var2 var3, ///
  nocons cov(ident) mle

**** get heritability and confidence interval

** confidence interval for heritability
** using standard error of heritability
** (delta method used once)

nlcom (heritability: exp(2*[lns1_1_1]_b[_cons]) /  ///
      ( exp(2*[lns1_1_1]_b[_cons]) + exp(2*[lnsig_e]_b[_cons])))

** confidence interval for heritability
** using probit transformation and appropriate standard error 
** (delta method used twice)
      
capture program drop _all
program define ciherit
  *ml display, first plus
  _coef_table, first plus
  noi _diparm lnsig_e lns1_1_1, label(heritability)                        ///
  func(exp(2*@2)/(exp(2*@1)+exp(2*@2)))                                    ///
  deriv( -2*exp(2*@1)*exp(2*@2)/(exp(2*@1)+exp(2*@2))^2                    ///
  -2*exp(4*@2)/(exp(2*@1)+exp(2*@2))^2+2*exp(2*@2)/(exp(2*@1)+exp(2*@2)))  ///
  level(95) ci(probit)
  disp in smcl in gr "{hline 13}" "{c BT}" "{hline 64}" _n
end

ciherit

 
